@@ -26,7 +26,8 @@ from process import ProcessLifecycleHandler, SshProcess, ProcessOutputHandler, \
 from report import Report
 from ssh_utils import get_rewritten_host_address, get_scp_command, \
     get_taktuk_connector_command, get_ssh_command
-from utils import name_from_cmdline, intr_cond_wait, intr_event_wait, get_port
+from utils import name_from_cmdline, intr_cond_wait, intr_event_wait, get_port, \
+    singleton_to_collection
 from traceback import format_exc
 from substitutions import get_caller_context, remote_substitute
 from time_utils import get_seconds, format_date
@@ -393,7 +394,7 @@ class Remote(Action):
 
     @hosts.setter
     def hosts(self, v):
-        self._hosts = get_hosts_list(v)
+        self._hosts = get_hosts_list(singleton_to_collection(v))
 
     def _args(self):
         return [ repr(self.cmd),
@@ -644,7 +645,7 @@ class TaktukRemote(Action):
 
     @hosts.setter
     def hosts(self, v):
-        self._hosts = get_hosts_list(v)
+        self._hosts = get_hosts_list(singleton_to_collection(v))
 
     def _args(self):
         return [ repr(self.cmd),
@@ -1523,7 +1524,7 @@ class ChainPut(SequentialActions):
 
     @hosts.setter
     def hosts(self, v):
-        self._hosts = get_unique_hosts_list(v)
+        self._hosts = get_unique_hosts_list(singleton_to_collection(v))
 
     def _init_actions(self):
         if len(self.hosts) > 0:
